//
//  MSLog.h
//  MSLog
//
//  Created by Paul Herzog on 17-Aug-2007.
//  Copyright 2007 MacSpeech, Inc. All rights reserved.
//

#import <Cocoa/Cocoa.h>

#pragma mark Simple Logging Configuration
// For setting the Logging Level
typedef enum {
   kLoggingLevelAll, kLoggingLevelDebug, kLoggingLevelInfo, kLoggingLevelWarn, kLoggingLevelError, kLoggingLevelFatal, kLoggingLevelNone
} LoggingLevel;


// Return YES if Log4Cocoa has already been initialized
BOOL MSLogInitialized();

// Initialize Log4Cocoa (if not already loaded)
typedef BOOL (*LOG_INIT_FUNC)(int);
BOOL MSLogInit(LoggingLevel level);

// Set the Logging Level
typedef void (*LOG_LEVEL_FUNC)(LoggingLevel);
void MSSetLogLevel(LoggingLevel level);

#pragma mark -
#pragma mark Simple Logging Support Macros
// Preprocessor Macros for Simple Logging
#define MS_L4_LOCATION lineNumber: __LINE__ fileName: __FILE__ methodName: __PRETTY_FUNCTION__

#define MS_L4LogDebug  MS_L4_LOCATION debug
#define MS_L4LogInfo   MS_L4_LOCATION info
#define MS_L4LogWarn   MS_L4_LOCATION warn
#define MS_L4LogError  MS_L4_LOCATION error
#define MS_L4LogFatal  MS_L4_LOCATION fatal
#define MS_L4LogFatal2  MS_L4_LOCATION Fatal

#pragma mark -
#pragma mark Simple Logging Macros
#define MSLogDebug(message,...)  [globalLogger MS_L4LogDebug:(message),##__VA_ARGS__]
#define MSLogInfo(message,...)  [globalLogger MS_L4LogInfo:(message),##__VA_ARGS__]
#define MSLogWarn(message,...)  [globalLogger MS_L4LogWarn:(message),##__VA_ARGS__]
#define MSLogError(message,...)  [globalLogger MS_L4LogError:(message),##__VA_ARGS__]
#define MSLogFatal(message,...)  [globalLogger MS_L4LogFatal:(message),##__VA_ARGS__]

#pragma mark -

// Simple Logging (Proxies Log4Cocoa)
@interface MSLog : NSObject {
   id logger;
}

#pragma mark Logging Methods
- (void)lineNumber:(int)lineNumber fileName:(const char *)fileName methodName:(const char *)methodName fatal:(NSString *)format, ...;
- (void)lineNumber:(int)lineNumber fileName:(const char *)fileName methodName:(const char *)methodName error:(NSString *)format, ...;
- (void)lineNumber:(int)lineNumber fileName:(const char *)fileName methodName:(const char *)methodName warn:(NSString *)format, ...;
- (void)lineNumber:(int)lineNumber fileName:(const char *)fileName methodName:(const char *)methodName info:(NSString *)format, ...;
- (void)lineNumber:(int)lineNumber fileName:(const char *)fileName methodName:(const char *)methodName debug:(NSString *)format, ...;
@end

// Log4Cocoa proxy instance used by the Simple Logging Macros
extern MSLog *globalLogger;
